import time
import py_shot_limit as shot_limit
import pytest


@pytest.fixture
def gcra_fixture():
    # Create a GCRA limiter allowing 2 requests every 1 second
    return shot_limit.Gcra(limit=2, period_secs=1)


# First two calls should succeed (burst)
# Third call should fail
# Wait for 0.6 seconds to let the bucket refill...
# Fourth call should now succeed
# Fifth call should fail again
def test_with_gcra(gcra_fixture):
    assert gcra_fixture.process()
    assert gcra_fixture.process()
    assert gcra_fixture.process() is False
    time.sleep(0.6)
    assert gcra_fixture.process()
    assert gcra_fixture.process() is False



import time
import py_shot_limit as shot_limit
import pytest


@pytest.fixture
def bucket_fixture():
    # Create a bucket with a capacity of 2, and that refills 1 token every
    # 5 seconds
    return shot_limit.TokenBucket(capacity=2, increment=1, period_secs=5)


# First two calls should succeed (burst)
# Third call should fail
# Wait for 6 seconds to let the bucket refill...
# Fourth call should now succeed
# Fifth call should fail again
def test_with_bucket(bucket_fixture):
    assert bucket_fixture.process()
    assert bucket_fixture.process()
    assert bucket_fixture.process() is False
    time.sleep(6)
    assert bucket_fixture.process()
    assert bucket_fixture.process() is False



import time
import py_shot_limit as shot_limit
import pytest


@pytest.fixture
def fixed_fixture():
    # Create a fixed window limiter allowing 2 requests every 1 second
    return shot_limit.FixedWindow(capacity=2, period_secs=1)


# First two calls should succeed (burst)
# Third call should fail
# Wait for 1.1 seconds to let the bucket refill...
# Fourth call should now succeed
# Fifth call should now succeed
# Sixth call should fail again
def test_with_fixed(fixed_fixture):
    assert fixed_fixture.process()
    assert fixed_fixture.process()
    assert fixed_fixture.process() is False
    time.sleep(1.1)
    assert fixed_fixture.process()
    assert fixed_fixture.process()
    assert fixed_fixture.process() is False
